@@ -1,24 +1,24 @@
 
 #define PACKAGE_NAME "am-utils"
 #define PACKAGE_TARNAME "am-utils"
-#define PACKAGE_VERSION "6.2a2"
-#define PACKAGE_STRING "am-utils 6.2a2"
+#define PACKAGE_VERSION "6.2a1"
+#define PACKAGE_STRING "am-utils 6.2a1"
 #define PACKAGE_BUGREPORT "https://bugzilla.am-utils.org/ or am-utils@am-utils.org"
 #define HOST_CPU "i686"
 #define HOST_VENDOR "pc"
 #define HOST_OS "linux"
 #define HOST_OS_NAME "linux"
-#define HOST_OS_VERSION "2.4.20-46.7.legacy"
+#define HOST_OS_VERSION "2.6.11-ts2+ezk"
 #define HOST_ARCH "i386"
-#define DISTRO_NAME "rh7.3"
-#define HOST_NAME "a-rh73.fsl.cs.sunysb.edu"
+#define DISTRO_NAME "rh8.0"
+#define HOST_NAME "dhcp49.fsl.cs.sunysb.edu"
 #define USER_NAME "ezk"
-#define CONFIG_DATE "Thu May 11 11:28:14 EDT 2006"
+#define CONFIG_DATE "Wed Sep 14 18:08:22 EDT 2005"
 #define PACKAGE_NAME "am-utils"
-#define PACKAGE_VERSION "6.2a2"
+#define PACKAGE_VERSION "6.2a1"
 #define PACKAGE_BUGREPORT "https://bugzilla.am-utils.org/ or am-utils@am-utils.org"
 #define PACKAGE "am-utils"
-#define VERSION "6.2a2"
+#define VERSION "6.2a1"
 #define DEBUG 1
 #define STDC_HEADERS 1
 #define HAVE_SYS_TYPES_H 1
@@ -32,12 +32,15 @@
 #define HAVE_UNISTD_H 1
 #define HAVE_DLFCN_H 1
 #ifdef __cplusplus
-void exit (int);
+#include <stdlib.h>
 #endif
 #define HOST_HEADER_VERSION "2.4.9-9"
 #define YYTEXT_POINTER 1
 #define HAVE_LIBRPCSVC 1
 #define HAVE_LIBNSL 1
+#define HAVE_LIBHESIOD 1
+#define HAVE_LIBLDAP 1
+#define HAVE_LDAP_ENABLE_CACHE 1
 #define HAVE_LIBRT 1
 #define HAVE_UNISTD_H 1
 #define HAVE_FORK 1
@@ -60,6 +63,7 @@ void exit (int);
 #define HAVE_GETDOMAINNAME 1
 #define HAVE_GETDTABLESIZE 1
 #define HAVE_GETHOSTNAME 1
+#define HAVE_GETIFADDRS 1
 #define HAVE_GETPAGESIZE 1
 #define HAVE_GETTIMEOFDAY 1
 #define HAVE_HASMNTOPT 1
@@ -85,8 +89,6 @@ void exit (int);
 #define HAVE_SIGNAL 1
 #define HAVE_SIGSUSPEND 1
 #define HAVE_SOCKET 1
-#define HAVE_STATFS 1
-#define HAVE_STATVFS 1
 #define HAVE_STRCASECMP 1
 #define HAVE_STRCHR 1
 #define HAVE_STRCSPN 1
@@ -104,6 +106,9 @@ void exit (int);
 #define HAVE_VSNPRINTF 1
 #define HAVE_WAIT3 1
 #define HAVE_WAITPID 1
+#define HAVE_HES_INIT 1
+#define HAVE_HESIOD_INIT 1
+#define HAVE_HESIOD_TO_BIND 1
 #define HAVE_CLNT_SPERRNO 1
 #define HAVE_HASMNTOPT 1
 #define HAVE_STRCASECMP 1
@@ -156,6 +161,7 @@ void exit (int);
 #define HAVE_SYS_WAIT_H 1
 #define HAVE_ARPA_NAMESER_H 1
 #define HAVE_ARPA_INET_H 1
+#define HAVE_GDBM_NDBM_H 1
 #define HAVE_LINUX_FS_H 1
 #define HAVE_LINUX_KDEV_T_H 1
 #define HAVE_LINUX_LIST_H 1
@@ -191,7 +197,6 @@ void exit (int);
 #define HAVE_SYS_SOCKET_H 1
 #define HAVE_SYS_STAT_H 1
 #define HAVE_SYS_STATFS_H 1
-#define HAVE_SYS_STATVFS_H 1
 #define HAVE_SYS_SYSCALL_H 1
 #define HAVE_SYS_SYSLOG_H 1
 #define HAVE_SYS_TIME_H 1
@@ -203,6 +208,7 @@ void exit (int);
 #define HAVE_CTYPE_H 1
 #define HAVE_ERRNO_H 1
 #define HAVE_FCNTL_H 1
+#define HAVE_IFADDRS_H 1
 #define HAVE_GRP_H 1
 #define HAVE_LIBGEN_H 1
 #define HAVE_LIMITS_H 1
@@ -225,6 +231,9 @@ void exit (int);
 #define HAVE_TIME_H 1
 #define HAVE_VARARGS_H 1
 #define HAVE_UNISTD_H 1
+#define HAVE_LBER_H 1
+#define HAVE_LDAP_H 1
+#define HAVE_HESIOD_H 1
 #define HAVE_LINUX_AUTO_FS_H 1
 #define HAVE_LINUX_AUTO_FS4_H 1
 #define HAVE_LINUX_LOOP_H 1
@@ -250,7 +259,6 @@ void exit (int);
 #define SVC_IN_ARG_TYPE caddr_t
 #define XDRPROC_T_TYPE xdrproc_t
 #define voidp void *
-#define HAVE_C99_VARARGS_MACROS 1
 #define HAVE_EXTERN_SYS_ERRLIST 1
 #define HAVE_EXTERN_OPTARG 1
 #define HAVE_EXTERN_CLNT_SPCREATEERROR 1
@@ -278,21 +286,23 @@ void exit (int);
 #define HAVE_EXTERN_VSNPRINTF 1
 #define HAVE_EXTERN_XDR_CALLMSG 1
 #define HAVE_EXTERN_XDR_OPAQUE_AUTH 1
+#define HAVE_EXTERN_LDAP_ENABLE_CACHE 1
 #define HAVE_LONG_FILE_NAMES 1
 #define HAVE_UNISTD_H 1
 #define HAVE_RESTARTABLE_SYSCALLS 1
 #define HAVE_NFS_ARGS_T_ACDIRMIN 1
-#define HAVE_NFS_ARGS_T_ACDIRMAX 1
 #define HAVE_NFS_ARGS_T_ACREGMIN 1
-#define HAVE_NFS_ARGS_T_ACREGMAX 1
 #define HAVE_NFS_ARGS_T_BSIZE 1
 #define HAVE_NFS_ARGS_T_FHSIZE 1
 #define HAVE_NFS_ARGS_T_NAMLEN 1
 #define HAVE_NFS_ARGS_T_VERSION 1
 #define HAVE_STRUCT_IFREQ_IFR_ADDR 1
+#define HAVE_STRUCT_IFADDRS_IFA_NEXT 1
 #define HAVE_MAP_FILE 1
 #define HAVE_MAP_SUN 1
 #define HAVE_MAP_EXEC 1
+#define HAVE_MAP_HESIOD 1
+#define HAVE_MAP_LDAP 1
 #define HAVE_MAP_NDBM 1
 #define HAVE_MAP_NIS 1
 #define HAVE_MAP_NISPLUS 1
@@ -304,7 +314,7 @@ void exit (int);
 #define HAVE_FS_NFS 1
 #define HAVE_FS_PCFS 1
 #define HAVE_FS_TMPFS 1
-#define HAVE_FS_UFS 1
+#define HAVE_FS_XFS 1
 #define HAVE_AMU_FS_AUTO 1
 #define HAVE_AMU_FS_DIRECT 1
 #define HAVE_AMU_FS_TOPLVL 1
@@ -318,7 +328,7 @@ void exit (int);
 #define HAVE_AMU_FS_UNION 1
 #define MOUNT_TYPE_NFS MNTTYPE_NFS
 #define MOUNT_TYPE_NFS3 MNTTYPE_NFS3
-#define MOUNT_TYPE_UFS "ext2"
+#define MOUNT_TYPE_XFS "xfs"
 #define MOUNT_TYPE_CDFS MNTTYPE_ISO9660
 #define MOUNT_TYPE_PCFS "vfat"
 #define MOUNT_TYPE_TMPFS "tmpfs"
@@ -327,7 +337,7 @@ void exit (int);
 #define MOUNT_TYPE_IGNORE MNTTYPE_IGNORE
 #define MNTTAB_TYPE_NFS "nfs"
 #define MNTTAB_TYPE_NFS3 "nfs"
-#define MNTTAB_TYPE_UFS "ext2"
+#define MNTTAB_TYPE_XFS "xfs"
 #define MNTTAB_TYPE_CDFS "iso9660"
 #define MNTTAB_TYPE_PCFS "vfat"
 #define MNTTAB_TYPE_TMPFS "tmpfs"
